agentle.agents.knowledge.document\_knowledge
============================================

.. automodule:: agentle.agents.knowledge.document_knowledge

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
      model_validator
   
   .. rubric:: Classes

   .. autosummary::
   
      BaseModel
      DocumentKnowledge
      Path
   